@@ -1,14 +1,19 @@
-__version__ = "1.2.1"
+__version__ = "1.3.0"
 
+from .data import SensorData, SensorUpdate
 from .description import SensorDescription
+from .device import DeviceKey
 from .device_class import DeviceClass
 from .library import SensorLibrary
 from .value import SensorValue
 
 __all__ = [
     "DeviceClass",
+    "DeviceKey",
+    "SensorData",
     "SensorDescription",
     "SensorDescription",
     "SensorLibrary",
+    "SensorUpdate",
     "SensorValue",
 ]
